@@ -76,10 +76,15 @@ def write_custom_tags(track: Track):
     audio_file.album = track.album
     audio_file.albumartist = track.albumartist
     audio_file.artist = track.artist
-    audio_file.date = track.date
+    audio_file.artists = track.artists
+    audio_file.country = track.album_obj.country
+    audio_file.date = track.album_obj.date
     audio_file.disc = track.disc
-    audio_file.disctotal = track.disc_total
+    audio_file.disctotal = track.album_obj.disc_total
     audio_file.genres = track.genres
+    audio_file.label = track.album_obj.label
+    audio_file.media = track.album_obj.media
+    audio_file.original_date = track.album_obj.original_date
     audio_file.title = track.title
     audio_file.track = track.track_num
 
